@@ -13,9 +13,9 @@ import py_mini_racer
 import requests
 from bs4 import BeautifulSoup
 
-from akshare.datasets import get_covid_js
-from akshare.event.cons import province_dict, city_dict
-from akshare.utils import demjson
+from PPshare.datasets import get_covid_js
+from PPshare.event.cons import province_dict, city_dict
+from PPshare.utils import demjson
 
 
 def _get_file_content(file: str = "covid.js") -> str:
