@@ -13,8 +13,8 @@ from io import BytesIO, StringIO
 import pandas as pd
 import requests
 
-from akshare.futures import cons
-from akshare.futures.requests_fun import requests_link
+from PPshare.futures import cons
+from PPshare.futures.requests_fun import requests_link
 
 calendar = cons.get_calendar()
 
